@@ -15,7 +15,7 @@ use HTML::TokeParser::Simple;
 use B::Deparse;
 
 use vars qw( $VERSION @EXPORT %munge_map );
-$VERSION = '0.47';
+$VERSION = '0.49';
 @EXPORT = qw( &shell );
 
 =head1 NAME
@@ -318,7 +318,13 @@ sub prompt_str {
 };
 
 sub request_dumper { print $_[1]->as_string };
-sub response_dumper { print $_[1]->as_string };
+sub response_dumper {
+  if (ref $_[1] eq 'ARRAY') {
+    print $_[1]->[0]->as_string;
+  } else {
+    print $_[1]->as_string;
+  }
+};
 
 sub re_or_string {
   my ($self,$arg) = @_;
@@ -1326,23 +1332,12 @@ Set basic authentication credentials.
 
 Syntax:
 
-  auth [authority realm] user password
-
-If you get back a 401, you can simply supply the matching
-user and password, as the authority and realm are already
-known :
-
-	>get http://www.example.com
-	Retrieving http://www.example.com(401)
-	http://www.example.com>auth corion secret
-	http://www.example.com>get http://www.example.com
-	Retrieving http://www.example.com(200)
-	http://www.example.com>
+  auth user password
 
 If you know the authority and the realm in advance, you can
 presupply the credentials, for example at the start of the script :
 
-	>auth www.example.com:80 secure_realm corion secret
+	>auth corion secret
 	>get http://www.example.com
 	Retrieving http://www.example.com(200)
 	http://www.example.com>
@@ -1351,38 +1346,23 @@ presupply the credentials, for example at the start of the script :
 
 sub run_auth {
     my ($self) = shift;
-    my ($authority, $realm, $user, $password);
+    my ($user, $password);
     if (scalar @_ == 2) {
-      unless ($self->agent->res) {
-        print "Can't guess authentification elements without a request or a realm.";
-        print "Use the four parameter version instead.";
-        return;
-      };
-
       ($user,$password) = @_;
       $password = "" if not defined $password;
 
       my $code = sub {
-          if ($self->agent->res->www_authenticate =~ /\brealm=(['"]?)(.*)\1/) {
-            $realm = $2
-          } else {
-            #$self->warn_user();
-            $realm = "";
-          };
-          $authority = $self->agent->{req}->uri->authority();
-          $self->agent->credentials($authority,$realm,$user => $password);
+          $self->agent->credentials($user => $password);
       };
       $code->();
       my $body = $self->munge_code($code);
 
       $self->add_history(
-          sprintf( q{my ($user,$password) = ('%s','%s')}, $user, $password),
+          sprintf( q{my ($user,$password) = ('%s','%s');}, $user, $password),
           $body,
       );
     } else {
-      ($authority, $realm, $user, $password) = @_;
-      $self->add_history( sprintf q{$agent->credentials('%s','%s','%s','%s');}, $authority,$realm,$user,$password);
-      $self->agent->credentials($authority,$realm,$user => $password);
+        $self->display_user_warning("Authentication only supports the two-argument form");
     };
 };
 
@@ -1987,7 +1967,7 @@ load their proxies from the environment.
 =head1 ONLINE HELP
 
 The online help feature is currently a bit broken in C<Term::Shell>,
-but a fix is in the works. Until then, you can reenable the
+but a fix is in the works. Until then, you can re-enable the
 dynamic online help by patching C<Term::Shell> :
 
 Remove the three lines
@@ -2060,7 +2040,7 @@ invocation of the shell like with CPAN :
 
 This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
-Copyright (C) 2002,2008 Max Maischein
+Copyright (C) 2002,2010 Max Maischein
 
 =head1 AUTHOR
 
@@ -2070,6 +2050,6 @@ Please contact me if you find bugs or otherwise improve the module. More tests a
 
 =head1 SEE ALSO
 
-L<WWW::Mechanize>,L<WWW::Mechanize::FormFiller>
+L<WWW::Mechanize>,L<WWW::Mechanize::FormFiller>,L<WWW::Mechanize::Firefox>
 
 =cut
